"use client";

import { useState, useEffect, useCallback } from "react";
import { useAttendance } from "@/lib/hooks/useAttendance";
import { useStudents } from "@/lib/hooks/useStudents";
import { Button } from "@/components/ui/button";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { Textarea } from "@/components/ui/textarea";
import { Tooltip, TooltipContent, TooltipTrigger } from "@/components/ui/tooltip";
import { Info } from "lucide-react";
import { toast } from "sonner";
import { Student } from "@/lib/types";
import { CalendarCheck, Loader2 } from "lucide-react";
import { useAuth } from "@/lib/hooks/useAuth";

interface AttendanceFormProps {
  classId: string;
  className: string;
  classLevel: string;
  date: string;
  students: Student[];
  onSuccess?: () => void;
}

export function AttendanceForm({ 
  classId, 
  className,
  classLevel,
  date, 
  students: initialStudents,
  onSuccess 
}: AttendanceFormProps) {
  const { markMultipleAttendances, getAttendanceByClass, loading: attendanceLoading } = useAttendance();
  const { user } = useAuth(); 
  const [students, setStudents] = useState<Student[]>([]);
  const [attendanceStatus, setAttendanceStatus] = useState<Record<string, string>>({});
  const [isLoading, setIsLoading] = useState(true);
  const [isSaving, setIsSaving] = useState(false);
  const [remarks, setRemarks] = useState<Record<string, string>>({});

  // Sync students with initialStudents
  useEffect(() => {
    setStudents(initialStudents);
  }, [initialStudents]);

  // Fetch attendance data and initialize status
  useEffect(() => {
    if (!classId || !date || initialStudents.length === 0) {
      setIsLoading(false);
      return;
    }

    const fetchAttendanceData = async () => {
      try {
        setIsLoading(true);
        const attendanceRecords = await getAttendanceByClass(classId, date, date);
        
        const initialStatus: Record<string, string> = {};
        const initialRemarks: Record<string, string> = {};
        
        initialStudents.forEach(student => {
          initialStatus[student.id] = "present";
          initialRemarks[student.id] = "";
        });

        attendanceRecords.forEach(record => {
          if (initialStatus.hasOwnProperty(record.studentId)) {
            initialStatus[record.studentId] = record.status;
            initialRemarks[record.studentId] = record.remarks || "";
          }
        });

        setAttendanceStatus(initialStatus);
        setRemarks(initialRemarks);
      } catch (error) {
        console.error("Error fetching attendance data:", error);
        toast.error("Failed to load attendance data");
      } finally {
        setIsLoading(false);
      }
    };
    
    fetchAttendanceData();
  }, [classId, date, initialStudents]);

  const handleRemarkChange = useCallback((studentId: string, value: string) => {
    setRemarks(prev => ({
      ...prev,
      [studentId]: value
    }));
  }, []);

  const handleStatusChange = useCallback((studentId: string, status: string) => {
    setAttendanceStatus(prev => ({
      ...prev,
      [studentId]: status
    }));
  }, []);

  const handleSubmit = async () => {
    setIsSaving(true);
    try {
      const attendanceRecords = students.map(student => ({
        date,
        classId,
        className,
        classLevel,
        studentId: student.id,
        status: attendanceStatus[student.id] as "present" | "absent" | "late",
        markedBy: {
          name: user?.name || "Unknown",
          timestamp: new Date().toISOString()
        },
        remarks: remarks[student.id] || ""
      }));

      await markMultipleAttendances(attendanceRecords);
      
      toast.success("Attendance saved successfully", {
        style: {
          background: '#4BB543', // Green color for success
          color: '#ffffff',
          border: '1px solid #3FAF3A',
        },
      });
      if (onSuccess) onSuccess();
    } catch (error) {
      console.error("Error saving attendance:", error);
      toast.error("Failed to save attendance", {
        style: {
          background: '#FF3333', // Red color for error
          color: '#ffffff',
          border: '1px solid #E60000',
        },
      });
    } finally {
      setIsSaving(false);
    }
  };

  if (isLoading) {
    return (
      <div className="flex items-center justify-center py-8">
        <Loader2 className="h-6 w-6 animate-spin mr-2" />
        <p>Loading attendance data...</p>
      </div>
    );
  }

  return (
    <div className="space-y-6">
      <div className="flex items-center justify-between">
        <div className="flex items-center">
          <CalendarCheck className="h-5 w-5 mr-2 text-primary" />
          <h3 className="text-lg font-medium">
            Attendance for {new Date(date).toLocaleDateString('en-GB', { 
              weekday: 'long', 
              year: 'numeric', 
              month: 'long', 
              day: 'numeric' 
            })}
          </h3>
        </div>
        <Button onClick={handleSubmit} disabled={isSaving}>
          {isSaving ? (
            <>
              <Loader2 className="h-4 w-4 animate-spin mr-2" />
              Saving...
            </>
          ) : (
            "Save Attendance"
          )}
        </Button>
      </div>

      {students.length === 0 ? (
        <div className="text-center py-8">
          <p className="text-muted-foreground">No students found in this class</p>
        </div>
      ) : (
        <div className="border rounded-md">
          <Table>
            <TableHeader>
              <TableRow>
                <TableHead>Student Name</TableHead>
                <TableHead>Status</TableHead>
                <TableHead>Remarks</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {students.map((student) => (
                <TableRow key={student.id}>
                  <TableCell>
                    <div className="font-medium">
                      {student.firstName} {student.lastName}
                    </div>
                  </TableCell>
                  <TableCell>
                    <Select
                      value={attendanceStatus[student.id]}
                      onValueChange={(value) => handleStatusChange(student.id, value)}
                    >
                      <SelectTrigger className="w-[120px]">
                        <SelectValue placeholder="Status" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="present">Present</SelectItem>
                        <SelectItem value="absent">Absent</SelectItem>
                        <SelectItem value="late">Late</SelectItem>
                      </SelectContent>
                    </Select>
                  </TableCell>
                  <TableCell>
                    <div className="relative">
                      <Textarea
                        value={remarks[student.id] || ""}
                        onChange={(e) => handleRemarkChange(student.id, e.target.value)}
                        placeholder="Add remarks (Optional)..."
                        className="min-h-[40px]"
                        rows={1}
                      />
                      {remarks[student.id] && (
                        <Tooltip>
                          <TooltipTrigger asChild>
                            <Info className="absolute right-2 top-2 h-4 w-4 text-muted-foreground" />
                          </TooltipTrigger>
                          <TooltipContent>
                            <p>{remarks[student.id]}</p>
                          </TooltipContent>
                        </Tooltip>
                      )}
                    </div>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        </div>
      )}
    </div>
  );
}  